@@ -11,7 +11,11 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Default 'ISecurityManagement' and 'IInteractionManagement' implementation
+"""
+Default :class:`zope.security.interfaces.ISecurityManagement` and
+:class:`zope.security.interfaces.IInteractionManagement` implementation.
+
+Note that this module itself provides those interfaces.
 """
 
 from zope.interface import moduleProvides
@@ -22,9 +26,22 @@ from zope.security.interfaces import ISecurityManagement
 from zope.security.interfaces import NoInteraction
 from zope.security.simplepolicies import ParanoidSecurityPolicy
 from zope.security._definitions import thread_local
-from zope.security._definitions import system_user # API?
+from zope.security._definitions import system_user
 
 
+__all__ = [
+    'system_user',
+    'getSecurityPolicy',
+    'setSecurityPolicy',
+    'queryInteraction',
+    'getInteraction',
+    'ExistingInteraction',
+    'newInteraction',
+    'endInteraction',
+    'restoreInteraction',
+    'checkPermission',
+]
+
 _defaultPolicy = ParanoidSecurityPolicy
 
 moduleProvides(
@@ -58,6 +75,7 @@ def setSecurityPolicy(aSecurityPolicy):
 #
 
 def queryInteraction():
+    """Return a current interaction, if there is one."""
     return getattr(thread_local, 'interaction', None)
 
 def getInteraction():
@@ -70,13 +88,16 @@ def getInteraction():
 class ExistingInteraction(ValueError,
                           AssertionError, #BBB
                          ):
-    pass
+    """
+    The exception that :func:`newInteraction` will raise if called
+    during an existing interaction.
+    """
 
 def newInteraction(*participations):
     """Start a new interaction."""
     if queryInteraction() is not None:
         raise ExistingInteraction("newInteraction called"
-                             " while another interaction is active.")
+                                  " while another interaction is active.")
     thread_local.interaction = getSecurityPolicy()(*participations)
 
 def endInteraction():
@@ -109,16 +130,16 @@ def restoreInteraction():
 def checkPermission(permission, object, interaction=None):
     """Return whether security policy allows permission on object.
 
-    'permission' is a permission name.
-
-    'object' is the object being accessed according to the permission.
-
-    'interaction' is an interaction, providing access to information
-    such as authenticated principals.  If it is None, the current
-    interaction is used.
-
-    checkPermission is guaranteed to return True if permission is
-    CheckerPublic or None.
+    :param str permission: A permission name.
+    :param object: The object being accessed according to the permission.
+    :param interaction: An interaction, providing access to information
+        such as authenticated principals.  If it is None, the current
+        interaction is used.
+    :return: A boolean value. ``checkPermission`` is guaranteed to
+        return ``True`` if *permission* is
+        :data:`zope.security.checker.CheckerPublic` or ``None``.
+    :raise NoInteraction: If there is no current interaction and no
+        interaction argument was given.
     """
     if permission is CheckerPublic or permission is None:
         return True
@@ -134,13 +155,9 @@ def _clear():
     global _defaultPolicy
     _defaultPolicy = ParanoidSecurityPolicy
 
-# XXX This code is used to support automated testing. However, it shouldn't be
-# here and needs to be refactored. The empty addCleanUp-method is a temporary
-# workaround to fix packages that depend on zope.security but don't have a
-# need for zope.testing.
 try:
     from zope.testing.cleanup import addCleanUp
-except ImportError: #pragma NO COVER
+except ImportError: # pragma: no cover
     pass
 else:
     addCleanUp(_clear)
