@@ -11,7 +11,13 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Simple 'ISecurityPolicy' implementations.
+"""
+Simple :class:`zope.security.interfaces.ISecurityPolicy` implementations.
+
+As a reminder, ``ISecurityPolicy`` objects are factories for producing
+:class:`zope.security.interfaces.IInteraction` objects. That means
+that the classes themselves are implementations of
+``ISecurityPolicy``.
 """
 import zope.interface
 
@@ -24,7 +30,13 @@ from zope.security._definitions import system_user
 @zope.interface.implementer(IInteraction)
 @zope.interface.provider(ISecurityPolicy)
 class ParanoidSecurityPolicy(object):
-    """Prohibit all access exctp to public items, or by explicit principals"""
+    """
+    Prohibit all access by any non-system principal, unless the item
+    is :data:`public <zope.security.checker.CheckerPublic>`.
+
+    This means that if there are no participations (and hence no
+    principals), then access is allowed.
+    """
 
     def __init__(self, *participations):
         self.participations = []
@@ -58,7 +70,9 @@ class ParanoidSecurityPolicy(object):
 
 @zope.interface.provider(ISecurityPolicy)
 class PermissiveSecurityPolicy(ParanoidSecurityPolicy):
-    """Allow all access."""
+    """
+    Allow all access.
+    """
 
     def checkPermission(self, permission, object):
         return True
